
#ifndef _C15_ev749_
#define _C15_ev749_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1402_13561(EIF_REFERENCE);
extern void F1402_13562(EIF_REFERENCE);
extern void EIF_Minit749(void);
extern void F1675_17597(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
